pub struct Vehicle<'a> {
pub v_vehiclekey: i64,
pub v_mfgr: VehicleManufacturerName,
pub v_brand: VehicleBrandName,
pub v_type: &'a str,
pub v_license: &'a str,
}Expand description
The VEHICLE table
The Display trait is implemented to format the line item data as a string in the default SpatialBench ‘tbl’ format.
1|goldenrod lavender spring chocolate lace|Manufacturer#1|Brand#13|PROMO BURNISHED COPPER|7|JUMBO PKG|901.00|ly. slyly ironi|
2|blush thistle blue yellow saddle|Manufacturer#1|Brand#13|LARGE BRUSHED BRASS|1|LG CASE|902.00|lar accounts amo|Fields
v_vehiclekey: i64Primary key
v_mfgr: VehicleManufacturerNameVehicle manufacturer.
v_brand: VehicleBrandNameVehicle brand.
v_type: &'a strVehicle type
v_license: &'a strVariable length comment