pub struct TextPool { /* private fields */ }Expand description
Pool of random text that follows SpatialBench grammar.
Implementations
Sourceimpl TextPool
impl TextPool
Sourcepub fn get_or_init_default() -> &'static Self
pub fn get_or_init_default() -> &'static Self
Returns the default text pool or initializes for the first time if that’s not already the case.
Sourcepub fn new(size: i32, distributions: &Distributions) -> Self
pub fn new(size: i32, distributions: &Distributions) -> Self
Returns a new text pool with a predefined size and set of distributions.