pub struct Customer<'a> {
pub c_custkey: i64,
pub c_name: CustomerName,
pub c_address: RandomAlphaNumericInstance,
pub c_region: &'a str,
pub c_nation: &'a str,
pub c_phone: PhoneNumberInstance,
}Expand description
The CUSTOMER table
The Display trait is implemented to format the line item data as a string in the default SpatialBench ‘tbl’ format.
1|Customer#000000001|IVhzIApeRb ot,c,E|15|25-989-741-2988|711.56|BUILDING|to the even, regular platelets. regular, ironic epitaphs nag e|
2|Customer#000000002|XSTf4,NCwDVaWNe6tEgvwfmRchLXak|13|23-768-687-3665|121.65|AUTOMOBILE|l accounts. blithely ironic theodolites integrate boldly: caref|Fields
c_custkey: i64Primary key
c_name: CustomerNameCustomer name
c_address: RandomAlphaNumericInstanceCustomer address
c_region: &'a strRegion name
c_nation: &'a strNation name
c_phone: PhoneNumberInstanceCustomer phone number